# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.compute.v1 import snapshot_schedule_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2
from yandex.cloud.compute.v1 import snapshot_schedule_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/compute/v1/snapshot_schedule_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SnapshotScheduleServiceStub(object):
    """A set of methods for managing snapshot schedules.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.GetSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2.SnapshotSchedule.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.CreateSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DeleteSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateDisks = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/UpdateDisks',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleDisksRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Disable = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Disable',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DisableSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Enable = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/Enable',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.EnableSnapshotScheduleRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsResponse.FromString,
                _registered_method=True)
        self.ListSnapshots = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/ListSnapshots',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsResponse.FromString,
                _registered_method=True)
        self.ListDisks = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/ListDisks',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksResponse.FromString,
                _registered_method=True)
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                _registered_method=True)
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.SnapshotScheduleService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class SnapshotScheduleServiceServicer(object):
    """A set of methods for managing snapshot schedules.
    """

    def Get(self, request, context):
        """Returns the specified snapshot schedule.

        To get the list of available snapshot schedules, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of snapshot schedules in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a snapshot schedule in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified snapshot schedule.

        The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified snapshot schedule.

        Deleting a snapshot schedule removes its data permanently and is irreversible. However, deleting a schedule
        does not delete any snapshots created by the schedule. You must delete snapshots separately.

        The schedule is deleted only after all snapshot creations and deletions triggered by the schedule are completed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDisks(self, request, context):
        """Updates the list of disks attached to the specified schedule.

        The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Disable(self, request, context):
        """Disables the specified snapshot schedule.

        The [SnapshotSchedule.status] is changed to `INACTIVE`: the schedule is interrupted, snapshots won't be created
        or deleted.

        The schedule is disabled only after all snapshot creations and deletions triggered by the schedule are completed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Enable(self, request, context):
        """Enables the specified snapshot schedule.

        The [SnapshotSchedule.status] is changed to `ACTIVE`: new disk snapshots will be created, old ones deleted
        (if [SnapshotSchedule.retention_policy] is specified).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSnapshots(self, request, context):
        """Retrieves the list of snapshots created by the specified snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDisks(self, request, context):
        """Retrieves the list of disks attached to the specified snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the snapshot schedule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SnapshotScheduleServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.GetSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2.SnapshotSchedule.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.CreateSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DeleteSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateDisks': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDisks,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleDisksRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Disable': grpc.unary_unary_rpc_method_handler(
                    servicer.Disable,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DisableSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Enable': grpc.unary_unary_rpc_method_handler(
                    servicer.Enable,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.EnableSnapshotScheduleRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsResponse.SerializeToString,
            ),
            'ListSnapshots': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSnapshots,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsResponse.SerializeToString,
            ),
            'ListDisks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDisks,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.SnapshotScheduleService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.compute.v1.SnapshotScheduleService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SnapshotScheduleService(object):
    """A set of methods for managing snapshot schedules.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.GetSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2.SnapshotSchedule.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotSchedulesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.CreateSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DeleteSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDisks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/UpdateDisks',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.UpdateSnapshotScheduleDisksRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Disable',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.DisableSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/Enable',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.EnableSnapshotScheduleRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSnapshots(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/ListSnapshots',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleSnapshotsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDisks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/ListDisks',
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__service__pb2.ListSnapshotScheduleDisksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.SnapshotScheduleService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TextClassifiers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFICATION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def classification_result(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClassificationResult]: ...
    def __init__(
        self,
        *,
        classification_result: collections.abc.Iterable[global___ClassificationResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classification_result", b"classification_result"]) -> None: ...

global___TextClassifiers = TextClassifiers

@typing.final
class ClassificationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFIER_FIELD_NUMBER: builtins.int
    CLASSIFIER_STATISTICS_FIELD_NUMBER: builtins.int
    classifier: builtins.str
    """Classifier name"""
    @property
    def classifier_statistics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClassifierStatistics]:
        """Classifier statistics"""

    def __init__(
        self,
        *,
        classifier: builtins.str = ...,
        classifier_statistics: collections.abc.Iterable[global___ClassifierStatistics] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classifier", b"classifier", "classifier_statistics", b"classifier_statistics"]) -> None: ...

global___ClassificationResult = ClassificationResult

@typing.final
class ClassifierStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    HISTOGRAMS_FIELD_NUMBER: builtins.int
    total_count: builtins.int
    """classifier total count"""
    @property
    def channel_number(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Channel number, null for whole talk"""

    @property
    def histograms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Histogram]:
        """Represents various histograms build on top of classifiers"""

    def __init__(
        self,
        *,
        channel_number: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        total_count: builtins.int = ...,
        histograms: collections.abc.Iterable[global___Histogram] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["channel_number", b"channel_number"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_number", b"channel_number", "histograms", b"histograms", "total_count", b"total_count"]) -> None: ...

global___ClassifierStatistics = ClassifierStatistics

@typing.final
class Histogram(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_VALUES_FIELD_NUMBER: builtins.int
    @property
    def count_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """histogram count values. For example:
        if len(count_values) = 2, it means that histogram is 50/50,
        if len(count_values) = 3 - [0] value represents first third, [1] - second third, [2] - last third, etc.
        """

    def __init__(
        self,
        *,
        count_values: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count_values", b"count_values"]) -> None: ...

global___Histogram = Histogram



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPayloadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret."""
    version_id: builtins.str
    """Optional ID of the version."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___GetPayloadRequest = GetPayloadRequest

@typing.final
class GetExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    FOLDER_AND_NAME_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    version_id: builtins.str
    @property
    def folder_and_name(self) -> global___FolderAndName: ...
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        folder_and_name: global___FolderAndName | None = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["folder_and_name", b"folder_and_name", "identifier", b"identifier", "secret_id", b"secret_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_and_name", b"folder_and_name", "identifier", b"identifier", "secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["identifier", b"identifier"]) -> typing.Literal["secret_id", "folder_and_name"] | None: ...

global___GetExRequest = GetExRequest

@typing.final
class FolderAndName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    secret_name: builtins.str
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "secret_name", b"secret_name"]) -> None: ...

global___FolderAndName = FolderAndName

@typing.final
class GetExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class EntriesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bytes
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    version_id: builtins.str
    @property
    def entries(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bytes]: ...
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
        entries: collections.abc.Mapping[builtins.str, builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___GetExResponse = GetExResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/group_mapping.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/group_mapping.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/organizationmanager/v1/group_mapping.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1dyandex/cloud/validation.proto\"f\n\x10GroupMappingItem\x12)\n\x11\x65xternal_group_id\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12\'\n\x11internal_group_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x0cGroupMapping\x12\x15\n\rfederation_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.group_mapping_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_GROUPMAPPINGITEM'].fields_by_name['external_group_id']._loaded_options = None
  _globals['_GROUPMAPPINGITEM'].fields_by_name['external_group_id']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_GROUPMAPPINGITEM'].fields_by_name['internal_group_id']._loaded_options = None
  _globals['_GROUPMAPPINGITEM'].fields_by_name['internal_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GROUPMAPPINGITEM']._serialized_start=127
  _globals['_GROUPMAPPINGITEM']._serialized_end=229
  _globals['_GROUPMAPPING']._serialized_start=231
  _globals['_GROUPMAPPING']._serialized_end=285
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Database(google.protobuf.message.Message):
    """A PostgreSQL Database resource. For more information, see
    the [Developer's Guide](/docs/managed-postgresql/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    LC_COLLATE_FIELD_NUMBER: builtins.int
    LC_CTYPE_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    TEMPLATE_DB_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster that the database belongs to."""
    owner: builtins.str
    """Name of the user assigned as the owner of the database."""
    lc_collate: builtins.str
    """POSIX locale for string sorting order.
    Can only be set at creation time.
    """
    lc_ctype: builtins.str
    """POSIX locale for character classification.
    Can only be set at creation time.
    """
    template_db: builtins.str
    """Name of the database template."""
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Extension]:
        """PostgreSQL extensions enabled for the database."""

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Deletion Protection inhibits deletion of the database

        Default value: `unspecified` (inherits cluster's deletion_protection)
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        owner: builtins.str = ...,
        lc_collate: builtins.str = ...,
        lc_ctype: builtins.str = ...,
        extensions: collections.abc.Iterable[global___Extension] | None = ...,
        template_db: builtins.str = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "deletion_protection", b"deletion_protection", "extensions", b"extensions", "lc_collate", b"lc_collate", "lc_ctype", b"lc_ctype", "name", b"name", "owner", b"owner", "template_db", b"template_db"]) -> None: ...

global___Database = Database

@typing.final
class Extension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the extension, e.g. `pg_trgm` or `pg_btree`.
    Extensions supported by Managed Service for PostgreSQL are [listed in the Developer's Guide](/docs/managed-postgresql/operations/extensions/cluster-extensions).
    """
    version: builtins.str
    """Version of the extension."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "version", b"version"]) -> None: ...

global___Extension = Extension

@typing.final
class DatabaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    LC_COLLATE_FIELD_NUMBER: builtins.int
    LC_CTYPE_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    TEMPLATE_DB_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the PostgreSQL database. 1-63 characters long."""
    owner: builtins.str
    """Name of the user to be assigned as the owner of the database.
    To get the list of available PostgreSQL users, make a [UserService.List] request.
    """
    lc_collate: builtins.str
    """POSIX locale for string sorting order.
    Can only be set at creation time.
    """
    lc_ctype: builtins.str
    """POSIX locale for character classification.
    Can only be set at creation time.
    """
    template_db: builtins.str
    """Name of the PostgreSQL database template."""
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Extension]:
        """PostgreSQL extensions to be enabled for the database."""

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Deletion Protection inhibits deletion of the database

        Default value: `unspecified` (inherits cluster's deletion_protection)
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        owner: builtins.str = ...,
        lc_collate: builtins.str = ...,
        lc_ctype: builtins.str = ...,
        extensions: collections.abc.Iterable[global___Extension] | None = ...,
        template_db: builtins.str = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "extensions", b"extensions", "lc_collate", b"lc_collate", "lc_ctype", b"lc_ctype", "name", b"name", "owner", b"owner", "template_db", b"template_db"]) -> None: ...

global___DatabaseSpec = DatabaseSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    connection_id: builtins.str
    description: builtins.str
    created_by: builtins.str
    modified_by: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FieldFilter]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        connection_id: builtins.str = ...,
        description: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_by: builtins.str = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        filters: collections.abc.Iterable[global___FieldFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "filters", b"filters", "id", b"id", "modified_at", b"modified_at", "modified_by", b"modified_by", "name", b"name"]) -> None: ...

global___Project = Project

@typing.final
class FieldFilter(google.protobuf.message.Message):
    """simple filters to match talks based on their connection metadata"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """connection metadata field key"""
    field_value: builtins.str
    """connection metadata field value"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        field_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field_value", b"field_value", "key", b"key"]) -> None: ...

global___FieldFilter = FieldFilter



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import chart_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_chart__widget__pb2
from yandex.cloud.monitoring.v3 import text_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_text__widget__pb2
from yandex.cloud.monitoring.v3 import title_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_title__widget__pb2
from yandex.cloud.monitoring.v3 import multi_source_chart_widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_multi__source__chart__widget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/monitoring/v3/widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a-yandex/cloud/monitoring/v3/chart_widget.proto\x1a,yandex/cloud/monitoring/v3/text_widget.proto\x1a-yandex/cloud/monitoring/v3/title_widget.proto\x1a:yandex/cloud/monitoring/v3/multi_source_chart_widget.proto\"\x9f\x03\n\x06Widget\x12\x43\n\x08position\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.monitoring.v3.Widget.LayoutPosition\x12\x36\n\x04text\x18\x02 \x01(\x0b\x32&.yandex.cloud.monitoring.v3.TextWidgetH\x00\x12\x38\n\x05title\x18\x03 \x01(\x0b\x32\'.yandex.cloud.monitoring.v3.TitleWidgetH\x00\x12\x38\n\x05\x63hart\x18\x05 \x01(\x0b\x32\'.yandex.cloud.monitoring.v3.ChartWidgetH\x00\x12P\n\x12multi_source_chart\x18\n \x01(\x0b\x32\x32.yandex.cloud.monitoring.v3.MultiSourceChartWidgetH\x00\x1a<\n\x0eLayoutPosition\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x12\t\n\x01w\x18\x03 \x01(\x03\x12\t\n\x01h\x18\x04 \x01(\x03\x42\x08\n\x06widgetJ\x04\x08\x04\x10\x05J\x04\x08\x06\x10\nBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_WIDGET']._serialized_start=272
  _globals['_WIDGET']._serialized_end=687
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_start=605
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_end=665
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.billable_object_pb2
import yandex.cloud.billing.v1.billing_account_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBillingAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the billing account to return.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___GetBillingAccountRequest = GetBillingAccountRequest

@typing.final
class ListBillingAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListBillingAccountsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListBillingAccountsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBillingAccountsRequest = ListBillingAccountsRequest

@typing.final
class ListBillingAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBillingAccountsRequest.page_size], use
    [next_page_token] as the value
    for the [ListBillingAccountsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def billing_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount]:
        """List of billing accounts."""

    def __init__(
        self,
        *,
        billing_accounts: collections.abc.Iterable[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_accounts", b"billing_accounts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBillingAccountsResponse = ListBillingAccountsResponse

@typing.final
class ListBillableObjectBindingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to list associated billable object bindings.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListBillableObjectBindingsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListBillableObjectBindingsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBillableObjectBindingsRequest = ListBillableObjectBindingsRequest

@typing.final
class ListBillableObjectBindingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLABLE_OBJECT_BINDINGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBillableObjectBindingsRequest.page_size], use
    [next_page_token] as the value
    for the [ListBillableObjectBindingsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def billable_object_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.billable_object_pb2.BillableObjectBinding]:
        """List of billable object bindings."""

    def __init__(
        self,
        *,
        billable_object_bindings: collections.abc.Iterable[yandex.cloud.billing.v1.billable_object_pb2.BillableObjectBinding] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billable_object_bindings", b"billable_object_bindings", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBillableObjectBindingsResponse = ListBillableObjectBindingsResponse

@typing.final
class BindBillableObjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BILLABLE_OBJECT_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to bind billable object.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    @property
    def billable_object(self) -> yandex.cloud.billing.v1.billable_object_pb2.BillableObject:
        """[yandex.cloud.billing.v1.BillableObject] to bind with billing account."""

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        billable_object: yandex.cloud.billing.v1.billable_object_pb2.BillableObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["billable_object", b"billable_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billable_object", b"billable_object", "billing_account_id", b"billing_account_id"]) -> None: ...

global___BindBillableObjectRequest = BindBillableObjectRequest

@typing.final
class BindBillableObjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLABLE_OBJECT_ID_FIELD_NUMBER: builtins.int
    billable_object_id: builtins.str
    """ID of the [yandex.cloud.billing.v1.BillableObject] that was bound to billing account."""
    def __init__(
        self,
        *,
        billable_object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billable_object_id", b"billable_object_id"]) -> None: ...

global___BindBillableObjectMetadata = BindBillableObjectMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CaptchaComplexity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CaptchaComplexityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CaptchaComplexity.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CAPTCHA_COMPLEXITY_UNSPECIFIED: _CaptchaComplexity.ValueType  # 0
    EASY: _CaptchaComplexity.ValueType  # 1
    """High chance to pass pre-check and easy advanced challenge."""
    MEDIUM: _CaptchaComplexity.ValueType  # 2
    """Medium chance to pass pre-check and normal advanced challenge."""
    HARD: _CaptchaComplexity.ValueType  # 3
    """Little chance to pass pre-check and hard advanced challenge."""
    FORCE_HARD: _CaptchaComplexity.ValueType  # 4
    """Impossible to pass pre-check and hard advanced challenge."""

class CaptchaComplexity(_CaptchaComplexity, metaclass=_CaptchaComplexityEnumTypeWrapper):
    """Captcha's complexity."""

CAPTCHA_COMPLEXITY_UNSPECIFIED: CaptchaComplexity.ValueType  # 0
EASY: CaptchaComplexity.ValueType  # 1
"""High chance to pass pre-check and easy advanced challenge."""
MEDIUM: CaptchaComplexity.ValueType  # 2
"""Medium chance to pass pre-check and normal advanced challenge."""
HARD: CaptchaComplexity.ValueType  # 3
"""Little chance to pass pre-check and hard advanced challenge."""
FORCE_HARD: CaptchaComplexity.ValueType  # 4
"""Impossible to pass pre-check and hard advanced challenge."""
global___CaptchaComplexity = CaptchaComplexity

class _CaptchaPreCheckType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CaptchaPreCheckTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CaptchaPreCheckType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CAPTCHA_PRE_CHECK_TYPE_UNSPECIFIED: _CaptchaPreCheckType.ValueType  # 0
    CHECKBOX: _CaptchaPreCheckType.ValueType  # 1
    """User must click the "I am not a robot" button."""
    SLIDER: _CaptchaPreCheckType.ValueType  # 2
    """User must move the slider from left to right."""

class CaptchaPreCheckType(_CaptchaPreCheckType, metaclass=_CaptchaPreCheckTypeEnumTypeWrapper):
    """Captcha's basic check type, see [Task types / Main task](/docs/smartcaptcha/concepts/tasks#main-task)."""

CAPTCHA_PRE_CHECK_TYPE_UNSPECIFIED: CaptchaPreCheckType.ValueType  # 0
CHECKBOX: CaptchaPreCheckType.ValueType  # 1
"""User must click the "I am not a robot" button."""
SLIDER: CaptchaPreCheckType.ValueType  # 2
"""User must move the slider from left to right."""
global___CaptchaPreCheckType = CaptchaPreCheckType

class _CaptchaChallengeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CaptchaChallengeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CaptchaChallengeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CAPTCHA_CHALLENGE_TYPE_UNSPECIFIED: _CaptchaChallengeType.ValueType  # 0
    IMAGE_TEXT: _CaptchaChallengeType.ValueType  # 1
    """Text recognition: The user has to type a distorted text from the picture into a special field."""
    SILHOUETTES: _CaptchaChallengeType.ValueType  # 2
    """Silhouettes: The user has to mark several icons from the picture in a particular order."""
    KALEIDOSCOPE: _CaptchaChallengeType.ValueType  # 3
    """Kaleidoscope: The user has to build a picture from individual parts by shuffling them using a slider."""

class CaptchaChallengeType(_CaptchaChallengeType, metaclass=_CaptchaChallengeTypeEnumTypeWrapper):
    """Additional task, see [Task types / Additional task](/docs/smartcaptcha/concepts/tasks#additional-task)."""

CAPTCHA_CHALLENGE_TYPE_UNSPECIFIED: CaptchaChallengeType.ValueType  # 0
IMAGE_TEXT: CaptchaChallengeType.ValueType  # 1
"""Text recognition: The user has to type a distorted text from the picture into a special field."""
SILHOUETTES: CaptchaChallengeType.ValueType  # 2
"""Silhouettes: The user has to mark several icons from the picture in a particular order."""
KALEIDOSCOPE: CaptchaChallengeType.ValueType  # 3
"""Kaleidoscope: The user has to build a picture from individual parts by shuffling them using a slider."""
global___CaptchaChallengeType = CaptchaChallengeType

@typing.final
class Captcha(google.protobuf.message.Message):
    """A Captcha resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CLIENT_KEY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_SITES_FIELD_NUMBER: builtins.int
    COMPLEXITY_FIELD_NUMBER: builtins.int
    STYLE_JSON_FIELD_NUMBER: builtins.int
    SUSPEND_FIELD_NUMBER: builtins.int
    TURN_OFF_HOSTNAME_CHECK_FIELD_NUMBER: builtins.int
    PRE_CHECK_TYPE_FIELD_NUMBER: builtins.int
    CHALLENGE_TYPE_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    OVERRIDE_VARIANTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the captcha."""
    folder_id: builtins.str
    """ID of the folder that the captcha belongs to."""
    cloud_id: builtins.str
    """ID of the cloud that the captcha belongs to."""
    client_key: builtins.str
    """Client key of the captcha, see [CAPTCHA keys](/docs/smartcaptcha/concepts/keys)."""
    name: builtins.str
    """Name of the captcha. The name is unique within the folder. 3-63 characters long."""
    complexity: global___CaptchaComplexity.ValueType
    """Complexity of the captcha."""
    style_json: builtins.str
    """JSON with variables to define the captcha appearance. For more details see generated JSON in cloud console."""
    suspend: builtins.bool
    """Determines that the captcha is currently in restricted mode, see [SmartCaptcha restricted mode](/docs/smartcaptcha/concepts/restricted-mode)."""
    turn_off_hostname_check: builtins.bool
    """Turn off host name check, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""
    pre_check_type: global___CaptchaPreCheckType.ValueType
    """Basic check type of the captcha."""
    challenge_type: global___CaptchaChallengeType.ValueType
    """Additional task type of the captcha."""
    deletion_protection: builtins.bool
    """Determines whether captcha is protected from being deleted."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def allowed_sites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of allowed host names, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityRule]:
        """List of security rules."""

    @property
    def override_variants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OverrideVariant]:
        """List of variants to use in security_rules"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        client_key: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        allowed_sites: collections.abc.Iterable[builtins.str] | None = ...,
        complexity: global___CaptchaComplexity.ValueType = ...,
        style_json: builtins.str = ...,
        suspend: builtins.bool = ...,
        turn_off_hostname_check: builtins.bool = ...,
        pre_check_type: global___CaptchaPreCheckType.ValueType = ...,
        challenge_type: global___CaptchaChallengeType.ValueType = ...,
        security_rules: collections.abc.Iterable[global___SecurityRule] | None = ...,
        deletion_protection: builtins.bool = ...,
        override_variants: collections.abc.Iterable[global___OverrideVariant] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowed_sites", b"allowed_sites", "challenge_type", b"challenge_type", "client_key", b"client_key", "cloud_id", b"cloud_id", "complexity", b"complexity", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "folder_id", b"folder_id", "id", b"id", "name", b"name", "override_variants", b"override_variants", "pre_check_type", b"pre_check_type", "security_rules", b"security_rules", "style_json", b"style_json", "suspend", b"suspend", "turn_off_hostname_check", b"turn_off_hostname_check"]) -> None: ...

global___Captcha = Captcha

@typing.final
class OverrideVariant(google.protobuf.message.Message):
    """OverrideVariant object. Contains the settings to override."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UUID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMPLEXITY_FIELD_NUMBER: builtins.int
    PRE_CHECK_TYPE_FIELD_NUMBER: builtins.int
    CHALLENGE_TYPE_FIELD_NUMBER: builtins.int
    uuid: builtins.str
    """Unique identifier of the variant."""
    description: builtins.str
    """Optional description of the rule. 0-512 characters long."""
    complexity: global___CaptchaComplexity.ValueType
    """Complexity of the captcha."""
    pre_check_type: global___CaptchaPreCheckType.ValueType
    """Basic check type of the captcha."""
    challenge_type: global___CaptchaChallengeType.ValueType
    """Additional task type of the captcha."""
    def __init__(
        self,
        *,
        uuid: builtins.str = ...,
        description: builtins.str = ...,
        complexity: global___CaptchaComplexity.ValueType = ...,
        pre_check_type: global___CaptchaPreCheckType.ValueType = ...,
        challenge_type: global___CaptchaChallengeType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["challenge_type", b"challenge_type", "complexity", b"complexity", "description", b"description", "pre_check_type", b"pre_check_type", "uuid", b"uuid"]) -> None: ...

global___OverrideVariant = OverrideVariant

@typing.final
class CaptchaSecretKey(google.protobuf.message.Message):
    """CaptchaSecretKey object. Contains captcha data that need to keep in secret."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_KEY_FIELD_NUMBER: builtins.int
    server_key: builtins.str
    """Server key of the captcha, see [CAPTCHA keys](/docs/smartcaptcha/concepts/keys)."""
    def __init__(
        self,
        *,
        server_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_key", b"server_key"]) -> None: ...

global___CaptchaSecretKey = CaptchaSecretKey

@typing.final
class SecurityRule(google.protobuf.message.Message):
    """SecurityRule object. Defines the condition and action: when and which variant to show."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    OVERRIDE_VARIANT_UUID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the rule. The name is unique within the captcha. 1-50 characters long."""
    priority: builtins.int
    """Priority of the rule. Lower value means higher priority."""
    description: builtins.str
    """Optional description of the rule. 0-512 characters long."""
    override_variant_uuid: builtins.str
    """Variant UUID to show in case of match the rule. Keep empty to use defaults."""
    @property
    def condition(self) -> global___Condition:
        """The condition for matching the rule."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        description: builtins.str = ...,
        condition: global___Condition | None = ...,
        override_variant_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["condition", b"condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["condition", b"condition", "description", b"description", "name", b"name", "override_variant_uuid", b"override_variant_uuid", "priority", b"priority"]) -> None: ...

global___SecurityRule = SecurityRule

@typing.final
class Condition(google.protobuf.message.Message):
    """Condition object. AND semantics implied."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StringMatcher(google.protobuf.message.Message):
        """StringMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXACT_MATCH_FIELD_NUMBER: builtins.int
        EXACT_NOT_MATCH_FIELD_NUMBER: builtins.int
        PREFIX_MATCH_FIELD_NUMBER: builtins.int
        PREFIX_NOT_MATCH_FIELD_NUMBER: builtins.int
        PIRE_REGEX_MATCH_FIELD_NUMBER: builtins.int
        PIRE_REGEX_NOT_MATCH_FIELD_NUMBER: builtins.int
        exact_match: builtins.str
        exact_not_match: builtins.str
        prefix_match: builtins.str
        prefix_not_match: builtins.str
        pire_regex_match: builtins.str
        pire_regex_not_match: builtins.str
        def __init__(
            self,
            *,
            exact_match: builtins.str = ...,
            exact_not_match: builtins.str = ...,
            prefix_match: builtins.str = ...,
            prefix_not_match: builtins.str = ...,
            pire_regex_match: builtins.str = ...,
            pire_regex_not_match: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["exact_match", b"exact_match", "exact_not_match", b"exact_not_match", "match", b"match", "pire_regex_match", b"pire_regex_match", "pire_regex_not_match", b"pire_regex_not_match", "prefix_match", b"prefix_match", "prefix_not_match", b"prefix_not_match"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["exact_match", b"exact_match", "exact_not_match", b"exact_not_match", "match", b"match", "pire_regex_match", b"pire_regex_match", "pire_regex_not_match", b"pire_regex_not_match", "prefix_match", b"prefix_match", "prefix_not_match", b"prefix_not_match"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["match", b"match"]) -> typing.Literal["exact_match", "exact_not_match", "prefix_match", "prefix_not_match", "pire_regex_match", "pire_regex_not_match"] | None: ...

    @typing.final
    class HostMatcher(google.protobuf.message.Message):
        """HostMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOSTS_FIELD_NUMBER: builtins.int
        @property
        def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.StringMatcher]:
            """List of hosts. OR semantics implied."""

        def __init__(
            self,
            *,
            hosts: collections.abc.Iterable[global___Condition.StringMatcher] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["hosts", b"hosts"]) -> None: ...

    @typing.final
    class UriMatcher(google.protobuf.message.Message):
        """UriMatcher object. AND semantics implied."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PATH_FIELD_NUMBER: builtins.int
        QUERIES_FIELD_NUMBER: builtins.int
        @property
        def path(self) -> global___Condition.StringMatcher:
            """Path of the URI [RFC3986](https://datatracker.ietf.org/doc/html/rfc3986#section-3.3)."""

        @property
        def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.QueryMatcher]:
            """List of query matchers. AND semantics implied."""

        def __init__(
            self,
            *,
            path: global___Condition.StringMatcher | None = ...,
            queries: collections.abc.Iterable[global___Condition.QueryMatcher] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["path", b"path"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["path", b"path", "queries", b"queries"]) -> None: ...

    @typing.final
    class QueryMatcher(google.protobuf.message.Message):
        """QueryMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Key of the query parameter."""
        @property
        def value(self) -> global___Condition.StringMatcher:
            """Value of the query parameter."""

        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Condition.StringMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class HeaderMatcher(google.protobuf.message.Message):
        """HeaderMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of header (case insensitive)."""
        @property
        def value(self) -> global___Condition.StringMatcher:
            """Value of the header."""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: global___Condition.StringMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    @typing.final
    class IpMatcher(google.protobuf.message.Message):
        """IpMatcher object. AND semantics implied."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IP_RANGES_MATCH_FIELD_NUMBER: builtins.int
        IP_RANGES_NOT_MATCH_FIELD_NUMBER: builtins.int
        GEO_IP_MATCH_FIELD_NUMBER: builtins.int
        GEO_IP_NOT_MATCH_FIELD_NUMBER: builtins.int
        @property
        def ip_ranges_match(self) -> global___Condition.IpRangesMatcher: ...
        @property
        def ip_ranges_not_match(self) -> global___Condition.IpRangesMatcher: ...
        @property
        def geo_ip_match(self) -> global___Condition.GeoIpMatcher: ...
        @property
        def geo_ip_not_match(self) -> global___Condition.GeoIpMatcher: ...
        def __init__(
            self,
            *,
            ip_ranges_match: global___Condition.IpRangesMatcher | None = ...,
            ip_ranges_not_match: global___Condition.IpRangesMatcher | None = ...,
            geo_ip_match: global___Condition.GeoIpMatcher | None = ...,
            geo_ip_not_match: global___Condition.GeoIpMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["geo_ip_match", b"geo_ip_match", "geo_ip_not_match", b"geo_ip_not_match", "ip_ranges_match", b"ip_ranges_match", "ip_ranges_not_match", b"ip_ranges_not_match"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["geo_ip_match", b"geo_ip_match", "geo_ip_not_match", b"geo_ip_not_match", "ip_ranges_match", b"ip_ranges_match", "ip_ranges_not_match", b"ip_ranges_not_match"]) -> None: ...

    @typing.final
    class IpRangesMatcher(google.protobuf.message.Message):
        """IpRangesMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IP_RANGES_FIELD_NUMBER: builtins.int
        @property
        def ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of IP ranges. OR semantics implied."""

        def __init__(
            self,
            *,
            ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["ip_ranges", b"ip_ranges"]) -> None: ...

    @typing.final
    class GeoIpMatcher(google.protobuf.message.Message):
        """GeoIpMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATIONS_FIELD_NUMBER: builtins.int
        @property
        def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """ISO 3166-1 alpha 2. OR semantics implied."""

        def __init__(
            self,
            *,
            locations: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["locations", b"locations"]) -> None: ...

    HOST_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    SOURCE_IP_FIELD_NUMBER: builtins.int
    @property
    def host(self) -> global___Condition.HostMatcher:
        """Host where captcha placed."""

    @property
    def uri(self) -> global___Condition.UriMatcher:
        """URI where captcha placed."""

    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.HeaderMatcher]:
        """Captcha request headers."""

    @property
    def source_ip(self) -> global___Condition.IpMatcher:
        """The IP address of the requester."""

    def __init__(
        self,
        *,
        host: global___Condition.HostMatcher | None = ...,
        uri: global___Condition.UriMatcher | None = ...,
        headers: collections.abc.Iterable[global___Condition.HeaderMatcher] | None = ...,
        source_ip: global___Condition.IpMatcher | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host", b"host", "source_ip", b"source_ip", "uri", b"uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "host", b"host", "source_ip", b"source_ip", "uri", b"uri"]) -> None: ...

global___Condition = Condition



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/tuning/v1/tuning_error.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/tuning/v1/tuning_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/ai/tuning/v1/tuning_error.proto\x12\x19yandex.cloud.ai.tuning.v1\"\xa9\x01\n\x0bTuningError\x12\x16\n\x0etuning_task_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.yandex.cloud.ai.tuning.v1.TuningError.Type\"6\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_TUNINGERROR']._serialized_start=76
  _globals['_TUNINGERROR']._serialized_end=245
  _globals['_TUNINGERROR_TYPE']._serialized_start=191
  _globals['_TUNINGERROR_TYPE']._serialized_end=245
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.apploadbalancer.v1.payload_pb2
import yandex.cloud.apploadbalancer.v1.tls_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LoadBalancingMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LoadBalancingModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LoadBalancingMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROUND_ROBIN: _LoadBalancingMode.ValueType  # 0
    """Round robin load balancing mode.

    All endpoints of the backend take their turns to receive requests attributed to the backend.
    """
    RANDOM: _LoadBalancingMode.ValueType  # 1
    """Random load balancing mode. Default value.

    For a request attributed to the backend, an endpoint that receives it is picked at random.
    """
    LEAST_REQUEST: _LoadBalancingMode.ValueType  # 2
    """Least request load balancing mode.

    To pick an endpoint that receives a request attributed to the backend, the power of two choices algorithm is used;
    that is, two endpoints are picked at random, and the request is sent to the one which has the fewest active
    requests.
    """
    MAGLEV_HASH: _LoadBalancingMode.ValueType  # 3
    """Maglev hashing load balancing mode.

    Each endpoint is hashed, and a hash table with 65537 rows is filled accordingly, so that every endpoint occupies
    the same amount of rows. An attribute of each request is also hashed by the same function (if session affinity is
    enabled for the backend group, the attribute to hash is specified in session affinity configuration). The row
    with the same number as the resulting value is looked up in the table to determine the endpoint that receives
    the request.

    If the backend group with session affinity enabled contains more than one backend with positive weight, endpoints
    for backends with `MAGLEV_HASH` load balancing mode are picked at `RANDOM` instead.
    """

class LoadBalancingMode(_LoadBalancingMode, metaclass=_LoadBalancingModeEnumTypeWrapper):
    """A load balancing mode resource.
    For details about the concept, see
    [documentation](/docs/application-load-balancer/concepts/backend-group#balancing-mode).
    """

ROUND_ROBIN: LoadBalancingMode.ValueType  # 0
"""Round robin load balancing mode.

All endpoints of the backend take their turns to receive requests attributed to the backend.
"""
RANDOM: LoadBalancingMode.ValueType  # 1
"""Random load balancing mode. Default value.

For a request attributed to the backend, an endpoint that receives it is picked at random.
"""
LEAST_REQUEST: LoadBalancingMode.ValueType  # 2
"""Least request load balancing mode.

To pick an endpoint that receives a request attributed to the backend, the power of two choices algorithm is used;
that is, two endpoints are picked at random, and the request is sent to the one which has the fewest active
requests.
"""
MAGLEV_HASH: LoadBalancingMode.ValueType  # 3
"""Maglev hashing load balancing mode.

Each endpoint is hashed, and a hash table with 65537 rows is filled accordingly, so that every endpoint occupies
the same amount of rows. An attribute of each request is also hashed by the same function (if session affinity is
enabled for the backend group, the attribute to hash is specified in session affinity configuration). The row
with the same number as the resulting value is looked up in the table to determine the endpoint that receives
the request.

If the backend group with session affinity enabled contains more than one backend with positive weight, endpoints
for backends with `MAGLEV_HASH` load balancing mode are picked at `RANDOM` instead.
"""
global___LoadBalancingMode = LoadBalancingMode

@typing.final
class BackendGroup(google.protobuf.message.Message):
    """A backend group resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/backend-group).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backend group. Generated at creation time."""
    name: builtins.str
    """Name of the backend group. The name is unique within the folder. The string length in characters is 3-63."""
    description: builtins.str
    """Description of the backend group. The string is 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the backend group belongs to."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Backend group labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        The maximum number of labels is 64.
        """

    @property
    def http(self) -> global___HttpBackendGroup:
        """List of HTTP backends that the backend group consists of."""

    @property
    def grpc(self) -> global___GrpcBackendGroup:
        """List of gRPC backends that the backend group consists of."""

    @property
    def stream(self) -> global___StreamBackendGroup:
        """List of stream (TCP) backends that the backend group consists of."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http: global___HttpBackendGroup | None = ...,
        grpc: global___GrpcBackendGroup | None = ...,
        stream: global___StreamBackendGroup | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend", b"backend", "created_at", b"created_at", "grpc", b"grpc", "http", b"http", "stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend", b"backend", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "grpc", b"grpc", "http", b"http", "id", b"id", "labels", b"labels", "name", b"name", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend", b"backend"]) -> typing.Literal["http", "grpc", "stream"] | None: ...

global___BackendGroup = BackendGroup

@typing.final
class StreamBackendGroup(google.protobuf.message.Message):
    """A stream (TCP) backend group resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKENDS_FIELD_NUMBER: builtins.int
    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamBackend]:
        """List of stream (TCP) backends."""

    @property
    def connection(self) -> global___ConnectionSessionAffinity:
        """Connection-based session affinity configuration.

        For now, a connection is defined only by an IP address of the client.
        """

    def __init__(
        self,
        *,
        backends: collections.abc.Iterable[global___StreamBackend] | None = ...,
        connection: global___ConnectionSessionAffinity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "session_affinity", b"session_affinity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backends", b"backends", "connection", b"connection", "session_affinity", b"session_affinity"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["session_affinity", b"session_affinity"]) -> typing.Literal["connection"] | None: ...

global___StreamBackendGroup = StreamBackendGroup

@typing.final
class HttpBackendGroup(google.protobuf.message.Message):
    """An HTTP backend group resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKENDS_FIELD_NUMBER: builtins.int
    CONNECTION_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    @property
    def backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpBackend]:
        """List of HTTP backends."""

    @property
    def connection(self) -> global___ConnectionSessionAffinity:
        """Connection-based session affinity configuration.

        For now, a connection is defined only by an IP address of the client.
        """

    @property
    def header(self) -> global___HeaderSessionAffinity:
        """HTTP-header-field-based session affinity configuration."""

    @property
    def cookie(self) -> global___CookieSessionAffinity:
        """Cookie-based session affinity configuration."""

    def __init__(
        self,
        *,
        backends: collections.abc.Iterable[global___HttpBackend] | None = ...,
        connection: global___ConnectionSessionAffinity | None = ...,
        header: global___HeaderSessionAffinity | None = ...,
        cookie: global___CookieSessionAffinity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "cookie", b"cookie", "header", b"header", "session_affinity", b"session_affinity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backends", b"backends", "connection", b"connection", "cookie", b"cookie", "header", b"header", "session_affinity", b"session_affinity"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["session_affinity", b"session_affinity"]) -> typing.Literal["connection", "header", "cookie"] | None: ...

global___HttpBackendGroup = HttpBackendGroup

@typing.final
class GrpcBackendGroup(google.protobuf.message.Message):
    """A gRPC backend group resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKENDS_FIELD_NUMBER: builtins.int
    CONNECTION_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    @property
    def backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GrpcBackend]:
        """List of gRPC backends."""

    @property
    def connection(self) -> global___ConnectionSessionAffinity:
        """Connection-based session affinity configuration.

        For now, a connection is defined only by an IP address of the client.
        """

    @property
    def header(self) -> global___HeaderSessionAffinity:
        """HTTP-header-field-based session affinity configuration."""

    @property
    def cookie(self) -> global___CookieSessionAffinity:
        """Cookie-based session affinity configuration."""

    def __init__(
        self,
        *,
        backends: collections.abc.Iterable[global___GrpcBackend] | None = ...,
        connection: global___ConnectionSessionAffinity | None = ...,
        header: global___HeaderSessionAffinity | None = ...,
        cookie: global___CookieSessionAffinity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "cookie", b"cookie", "header", b"header", "session_affinity", b"session_affinity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backends", b"backends", "connection", b"connection", "cookie", b"cookie", "header", b"header", "session_affinity", b"session_affinity"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["session_affinity", b"session_affinity"]) -> typing.Literal["connection", "header", "cookie"] | None: ...

global___GrpcBackendGroup = GrpcBackendGroup

@typing.final
class HeaderSessionAffinity(google.protobuf.message.Message):
    """A resource for HTTP-header-field-based session affinity configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    """Name of the HTTP header field that is used for session affinity."""
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["header_name", b"header_name"]) -> None: ...

global___HeaderSessionAffinity = HeaderSessionAffinity

@typing.final
class CookieSessionAffinity(google.protobuf.message.Message):
    """A resource for cookie-based session affinity configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the cookie that is used for session affinity."""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum age of cookies that are generated for sessions.

        If set to `0`, session cookies are used, which are stored by clients in temporary memory and are deleted
        on client restarts.

        If not set, the balancer does not generate cookies and only uses incoming ones for establishing session affinity.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "ttl", b"ttl"]) -> None: ...

global___CookieSessionAffinity = CookieSessionAffinity

@typing.final
class ConnectionSessionAffinity(google.protobuf.message.Message):
    """A resource for connection-based session affinity configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_IP_FIELD_NUMBER: builtins.int
    source_ip: builtins.bool
    """Specifies whether an IP address of the client is used to define a connection for session affinity."""
    def __init__(
        self,
        *,
        source_ip: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source_ip", b"source_ip"]) -> None: ...

global___ConnectionSessionAffinity = ConnectionSessionAffinity

@typing.final
class LoadBalancingConfig(google.protobuf.message.Message):
    """A load balancing configuration resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PANIC_THRESHOLD_FIELD_NUMBER: builtins.int
    LOCALITY_AWARE_ROUTING_PERCENT_FIELD_NUMBER: builtins.int
    STRICT_LOCALITY_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    panic_threshold: builtins.int
    """Threshold for panic mode.

    If percentage of healthy backends in the group drops below threshold,
    panic mode will be activated and traffic will be routed to all backends, regardless of their health check status.
    This helps to avoid overloading healthy backends.
    For details about panic mode, see [documentation](/docs/application-load-balancer/concepts/backend-group#panic-mode).

    If the value is `0`, panic mode will never be activated and traffic is routed only to healthy backends at all times.

    Default value: `0`.
    """
    locality_aware_routing_percent: builtins.int
    """Percentage of traffic that a load balancer node sends to healthy backends in its availability zone.
    The rest is divided equally between other zones. For details about zone-aware routing, see
    [documentation](/docs/application-load-balancer/concepts/backend-group#locality).

    If there are no healthy backends in an availability zone, all the traffic is divided between other zones.

    If [strict_locality] is `true`, the specified value is ignored.
    A load balancer node sends all the traffic within its availability zone, regardless of backends' health.

    Default value: `0`.
    """
    strict_locality: builtins.bool
    """Specifies whether a load balancer node should only send traffic to backends in its availability zone,
    regardless of their health, and ignore backends in other zones.

    If set to `true` and there are no healthy backends in the zone, the node in this zone will respond
    to incoming traffic with errors.
    For details about strict locality, see [documentation](/docs/application-load-balancer/concepts/backend-group#locality).

    If `strict_locality` is `true`, the value specified in [locality_aware_routing_percent] is ignored.

    Default value: `false`.
    """
    mode: global___LoadBalancingMode.ValueType
    """Load balancing mode for the backend.

    For details about load balancing modes, see
    [documentation](/docs/application-load-balancer/concepts/backend-group#balancing-mode).
    """
    def __init__(
        self,
        *,
        panic_threshold: builtins.int = ...,
        locality_aware_routing_percent: builtins.int = ...,
        strict_locality: builtins.bool = ...,
        mode: global___LoadBalancingMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["locality_aware_routing_percent", b"locality_aware_routing_percent", "mode", b"mode", "panic_threshold", b"panic_threshold", "strict_locality", b"strict_locality"]) -> None: ...

global___LoadBalancingConfig = LoadBalancingConfig

@typing.final
class StreamBackend(google.protobuf.message.Message):
    """A stream (TCP) backend resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BACKEND_WEIGHT_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_CONFIG_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    HEALTHCHECKS_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    ENABLE_PROXY_PROTOCOL_FIELD_NUMBER: builtins.int
    KEEP_CONNECTIONS_ON_HOST_HEALTH_FAILURE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the backend."""
    port: builtins.int
    """Port used by all targets to receive traffic."""
    enable_proxy_protocol: builtins.bool
    """If set, proxy protocol will be enabled for this backend."""
    keep_connections_on_host_health_failure: builtins.bool
    """If a backend host becomes unhealthy (as determined by the configured health checks),
    keep connections to the failed host.
    """
    @property
    def backend_weight(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Backend weight. Traffic is distributed between backends of a backend group according to their weights.

        Weights must be set either for all backends in a group or for none of them.
        Setting no weights is the same as setting equal non-zero weights for all backends.

        If the weight is non-positive, traffic is not sent to the backend.
        """

    @property
    def load_balancing_config(self) -> global___LoadBalancingConfig:
        """Load balancing configuration for the backend."""

    @property
    def target_groups(self) -> global___TargetGroupsBackend:
        """Target groups that belong to the backend. For details about target groups, see
        [documentation](/docs/application-load-balancer/concepts/target-group).
        """

    @property
    def healthchecks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheck]:
        """Health checks to perform on targets from target groups.
        For details about health checking, see [documentation](/docs/application-load-balancer/concepts/backend-group#health-checks).

        If no health checks are specified, active health checking is not performed.
        """

    @property
    def tls(self) -> global___BackendTls:
        """Settings for TLS connections between load balancer nodes and backend targets.

        If specified, the load balancer establishes TLS-encrypted TCP connections with targets and compares received
        certificates with the one specified in [BackendTls.validation_context].
        If not specified, the load balancer establishes unencrypted TCP connections with targets.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        backend_weight: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        load_balancing_config: global___LoadBalancingConfig | None = ...,
        port: builtins.int = ...,
        target_groups: global___TargetGroupsBackend | None = ...,
        healthchecks: collections.abc.Iterable[global___HealthCheck] | None = ...,
        tls: global___BackendTls | None = ...,
        enable_proxy_protocol: builtins.bool = ...,
        keep_connections_on_host_health_failure: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "load_balancing_config", b"load_balancing_config", "target_groups", b"target_groups", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "enable_proxy_protocol", b"enable_proxy_protocol", "healthchecks", b"healthchecks", "keep_connections_on_host_health_failure", b"keep_connections_on_host_health_failure", "load_balancing_config", b"load_balancing_config", "name", b"name", "port", b"port", "target_groups", b"target_groups", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend_type", b"backend_type"]) -> typing.Literal["target_groups"] | None: ...

global___StreamBackend = StreamBackend

@typing.final
class HttpBackend(google.protobuf.message.Message):
    """An HTTP backend resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BACKEND_WEIGHT_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_CONFIG_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    STORAGE_BUCKET_FIELD_NUMBER: builtins.int
    HEALTHCHECKS_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    USE_HTTP2_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the backend."""
    port: builtins.int
    """Port used by all targets to receive traffic."""
    use_http2: builtins.bool
    """Enables HTTP/2 usage in connections between load balancer nodes and backend targets.

    Default value: `false`, HTTP/1.1 is used.
    """
    @property
    def backend_weight(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Backend weight. Traffic is distributed between backends of a backend group according to their weights.

        Weights must be set either for all backends in a group or for none of them.
        Setting no weights is the same as setting equal non-zero weights for all backends.

        If the weight is non-positive, traffic is not sent to the backend.
        """

    @property
    def load_balancing_config(self) -> global___LoadBalancingConfig:
        """Load balancing configuration for the backend."""

    @property
    def target_groups(self) -> global___TargetGroupsBackend:
        """Target groups that belong to the backend. For details about target groups, see
        [documentation](/docs/application-load-balancer/concepts/target-group).
        """

    @property
    def storage_bucket(self) -> global___StorageBucketBackend:
        """Object Storage bucket to use as the backend. For details about buckets, see
        [documentation](/docs/storage/concepts/bucket).

        If a bucket is used as a backend, the list of bucket objects and the objects themselves must be publicly
        accessible. For instructions, see [documentation](/docs/storage/operations/buckets/bucket-availability).
        """

    @property
    def healthchecks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheck]:
        """Health checks to perform on targets from target groups.
        For details about health checking, see [documentation](/docs/application-load-balancer/concepts/backend-group#health-checks).

        If no health checks are specified, active health checking is not performed.
        """

    @property
    def tls(self) -> global___BackendTls:
        """Settings for TLS connections between load balancer nodes and backend targets.

        If specified, the load balancer establishes HTTPS (HTTP over TLS) connections with targets
        and compares received certificates with the one specified in [BackendTls.validation_context].
        If not specified, the load balancer establishes unencrypted HTTP connections with targets.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        backend_weight: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        load_balancing_config: global___LoadBalancingConfig | None = ...,
        port: builtins.int = ...,
        target_groups: global___TargetGroupsBackend | None = ...,
        storage_bucket: global___StorageBucketBackend | None = ...,
        healthchecks: collections.abc.Iterable[global___HealthCheck] | None = ...,
        tls: global___BackendTls | None = ...,
        use_http2: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "load_balancing_config", b"load_balancing_config", "storage_bucket", b"storage_bucket", "target_groups", b"target_groups", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "healthchecks", b"healthchecks", "load_balancing_config", b"load_balancing_config", "name", b"name", "port", b"port", "storage_bucket", b"storage_bucket", "target_groups", b"target_groups", "tls", b"tls", "use_http2", b"use_http2"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend_type", b"backend_type"]) -> typing.Literal["target_groups", "storage_bucket"] | None: ...

global___HttpBackend = HttpBackend

@typing.final
class GrpcBackend(google.protobuf.message.Message):
    """A gRPC backend resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BACKEND_WEIGHT_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_CONFIG_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    HEALTHCHECKS_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the backend."""
    port: builtins.int
    """Port used by all targets to receive traffic."""
    @property
    def backend_weight(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Backend weight. Traffic is distributed between backends of a backend group according to their weights.

        Weights must be set either for all backends of a group or for none of them.
        Setting no weights is the same as setting equal non-zero weights for all backends.

        If the weight is non-positive, traffic is not sent to the backend.
        """

    @property
    def load_balancing_config(self) -> global___LoadBalancingConfig:
        """Load balancing configuration for the backend."""

    @property
    def target_groups(self) -> global___TargetGroupsBackend:
        """Target groups that belong to the backend."""

    @property
    def healthchecks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheck]:
        """Health checks to perform on targets from target groups.
        For details about health checking, see [documentation](/docs/application-load-balancer/concepts/backend-group#health-checks).

        If no health checks are specified, active health checking is not performed.
        """

    @property
    def tls(self) -> global___BackendTls:
        """Settings for TLS connections between load balancer nodes and backend targets.

        If specified, the load balancer establishes HTTPS (HTTP over TLS) connections with targets
        and compares received certificates with the one specified in [BackendTls.validation_context].
        If not specified, the load balancer establishes unencrypted HTTP connections with targets.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        backend_weight: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        load_balancing_config: global___LoadBalancingConfig | None = ...,
        port: builtins.int = ...,
        target_groups: global___TargetGroupsBackend | None = ...,
        healthchecks: collections.abc.Iterable[global___HealthCheck] | None = ...,
        tls: global___BackendTls | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "load_balancing_config", b"load_balancing_config", "target_groups", b"target_groups", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend_type", b"backend_type", "backend_weight", b"backend_weight", "healthchecks", b"healthchecks", "load_balancing_config", b"load_balancing_config", "name", b"name", "port", b"port", "target_groups", b"target_groups", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend_type", b"backend_type"]) -> typing.Literal["target_groups"] | None: ...

global___GrpcBackend = GrpcBackend

@typing.final
class TargetGroupsBackend(google.protobuf.message.Message):
    """A resource for target groups that belong to the backend."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def target_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of ID's of target groups that belong to the backend.

        To get the ID's of all available target groups, make a [TargetGroupService.List] request.
        """

    def __init__(
        self,
        *,
        target_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_ids", b"target_group_ids"]) -> None: ...

global___TargetGroupsBackend = TargetGroupsBackend

@typing.final
class PlaintextTransportSettings(google.protobuf.message.Message):
    """Transport settings to be used instead of the settings configured per-cluster"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PlaintextTransportSettings = PlaintextTransportSettings

@typing.final
class SecureTransportSettings(google.protobuf.message.Message):
    """Transport settings to be used instead of the settings configured per-cluster"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNI_FIELD_NUMBER: builtins.int
    VALIDATION_CONTEXT_FIELD_NUMBER: builtins.int
    sni: builtins.str
    """SNI string for TLS connections."""
    @property
    def validation_context(self) -> yandex.cloud.apploadbalancer.v1.tls_pb2.ValidationContext:
        """Validation context for backend TLS connections."""

    def __init__(
        self,
        *,
        sni: builtins.str = ...,
        validation_context: yandex.cloud.apploadbalancer.v1.tls_pb2.ValidationContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["validation_context", b"validation_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["sni", b"sni", "validation_context", b"validation_context"]) -> None: ...

global___SecureTransportSettings = SecureTransportSettings

@typing.final
class BackendTls(google.protobuf.message.Message):
    """A resource for backend TLS settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNI_FIELD_NUMBER: builtins.int
    VALIDATION_CONTEXT_FIELD_NUMBER: builtins.int
    sni: builtins.str
    """Server Name Indication (SNI) string for TLS connections."""
    @property
    def validation_context(self) -> yandex.cloud.apploadbalancer.v1.tls_pb2.ValidationContext:
        """Validation context for TLS connections."""

    def __init__(
        self,
        *,
        sni: builtins.str = ...,
        validation_context: yandex.cloud.apploadbalancer.v1.tls_pb2.ValidationContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["validation_context", b"validation_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["sni", b"sni", "validation_context", b"validation_context"]) -> None: ...

global___BackendTls = BackendTls

@typing.final
class StorageBucketBackend(google.protobuf.message.Message):
    """A resource for Object Storage bucket used as a backend. For details about the concept,
    see [documentation](/docs/storage/concepts/bucket).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """Name of the bucket."""
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket"]) -> None: ...

global___StorageBucketBackend = StorageBucketBackend

@typing.final
class HealthCheck(google.protobuf.message.Message):
    """A health check resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/backend-group#health-checks).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StreamHealthCheck(google.protobuf.message.Message):
        """A resource for TCP stream health check settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SEND_FIELD_NUMBER: builtins.int
        RECEIVE_FIELD_NUMBER: builtins.int
        @property
        def send(self) -> yandex.cloud.apploadbalancer.v1.payload_pb2.Payload:
            """Message sent to targets during TCP data transfer.

            If not specified, no data is sent to the target.
            """

        @property
        def receive(self) -> yandex.cloud.apploadbalancer.v1.payload_pb2.Payload:
            """Data that must be contained in the messages received from targets for a successful health check.

            If not specified, no messages are expected from targets, and those that are received are not checked.
            """

        def __init__(
            self,
            *,
            send: yandex.cloud.apploadbalancer.v1.payload_pb2.Payload | None = ...,
            receive: yandex.cloud.apploadbalancer.v1.payload_pb2.Payload | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["receive", b"receive", "send", b"send"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["receive", b"receive", "send", b"send"]) -> None: ...

    @typing.final
    class HttpHealthCheck(google.protobuf.message.Message):
        """A resource for HTTP health check settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOST_FIELD_NUMBER: builtins.int
        PATH_FIELD_NUMBER: builtins.int
        USE_HTTP2_FIELD_NUMBER: builtins.int
        EXPECTED_STATUSES_FIELD_NUMBER: builtins.int
        host: builtins.str
        """Value for the HTTP/1.1 `Host` header or the HTTP/2 `:authority` pseudo-header used in requests to targets."""
        path: builtins.str
        """HTTP path used in requests to targets: request URI for HTTP/1.1 request line
        or value for the HTTP/2 `:path` pseudo-header.
        """
        use_http2: builtins.bool
        """Enables HTTP/2 usage in health checks.

        Default value: `false`, HTTP/1.1 is used.
        """
        @property
        def expected_statuses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
            """A list of HTTP response statuses considered healthy.
            By default only 200 HTTP status code considered healthy.
            """

        def __init__(
            self,
            *,
            host: builtins.str = ...,
            path: builtins.str = ...,
            use_http2: builtins.bool = ...,
            expected_statuses: collections.abc.Iterable[builtins.int] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["expected_statuses", b"expected_statuses", "host", b"host", "path", b"path", "use_http2", b"use_http2"]) -> None: ...

    @typing.final
    class GrpcHealthCheck(google.protobuf.message.Message):
        """A resource for gRPC health check settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERVICE_NAME_FIELD_NUMBER: builtins.int
        service_name: builtins.str
        """Name of the gRPC service to be checked.

        If not specified, overall health is checked.

        For details about the concept, see [GRPC Health Checking Protocol](https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
        """
        def __init__(
            self,
            *,
            service_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["service_name", b"service_name"]) -> None: ...

    TIMEOUT_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    INTERVAL_JITTER_PERCENT_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    HEALTHCHECK_PORT_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    interval_jitter_percent: builtins.float
    healthy_threshold: builtins.int
    """Number of consecutive successful health checks required to mark an unhealthy target as healthy.

    Both `0` and `1` values amount to one successful check required.

    The value is ignored when a load balancer is initialized; a target is marked healthy after one successful check.

    Default value: `0`.
    """
    unhealthy_threshold: builtins.int
    """Number of consecutive failed health checks required to mark a healthy target as unhealthy.

    Both `0` and `1` values amount to one unsuccessful check required.

    The value is ignored if a health check is failed due to an HTTP `503 Service Unavailable` response from the target
    (not applicable to TCP stream health checks). The target is immediately marked unhealthy.

    Default value: `0`.
    """
    healthcheck_port: builtins.int
    """Port used for health checks.

    If not specified, the backend port ([HttpBackend.port] or [GrpcBackend.port]) is used for health checks.
    """
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Health check timeout.

        The timeout is the time allowed for the target to respond to a check.
        If the target doesn't respond in time, the check is considered failed.
        """

    @property
    def interval(self) -> google.protobuf.duration_pb2.Duration:
        """Base interval between consecutive health checks."""

    @property
    def stream(self) -> global___HealthCheck.StreamHealthCheck:
        """TCP stream health check settings."""

    @property
    def http(self) -> global___HealthCheck.HttpHealthCheck:
        """HTTP health check settings."""

    @property
    def grpc(self) -> global___HealthCheck.GrpcHealthCheck:
        """gRPC health check settings."""

    @property
    def plaintext(self) -> global___PlaintextTransportSettings: ...
    @property
    def tls(self) -> global___SecureTransportSettings: ...
    def __init__(
        self,
        *,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        interval: google.protobuf.duration_pb2.Duration | None = ...,
        interval_jitter_percent: builtins.float = ...,
        healthy_threshold: builtins.int = ...,
        unhealthy_threshold: builtins.int = ...,
        healthcheck_port: builtins.int = ...,
        stream: global___HealthCheck.StreamHealthCheck | None = ...,
        http: global___HealthCheck.HttpHealthCheck | None = ...,
        grpc: global___HealthCheck.GrpcHealthCheck | None = ...,
        plaintext: global___PlaintextTransportSettings | None = ...,
        tls: global___SecureTransportSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["grpc", b"grpc", "healthcheck", b"healthcheck", "http", b"http", "interval", b"interval", "plaintext", b"plaintext", "stream", b"stream", "timeout", b"timeout", "tls", b"tls", "transport_settings", b"transport_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["grpc", b"grpc", "healthcheck", b"healthcheck", "healthcheck_port", b"healthcheck_port", "healthy_threshold", b"healthy_threshold", "http", b"http", "interval", b"interval", "interval_jitter_percent", b"interval_jitter_percent", "plaintext", b"plaintext", "stream", b"stream", "timeout", b"timeout", "tls", b"tls", "transport_settings", b"transport_settings", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["healthcheck", b"healthcheck"]) -> typing.Literal["stream", "http", "grpc"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["transport_settings", b"transport_settings"]) -> typing.Literal["plaintext", "tls"] | None: ...

global___HealthCheck = HealthCheck



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BatchInferenceTaskStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchInferenceTaskStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchInferenceTaskStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BATCH_INFERENCE_TASK_STATUS_UNSPECIFIED: _BatchInferenceTaskStatus.ValueType  # 0
    CREATED: _BatchInferenceTaskStatus.ValueType  # 1
    PENDING: _BatchInferenceTaskStatus.ValueType  # 2
    IN_PROGRESS: _BatchInferenceTaskStatus.ValueType  # 3
    COMPLETED: _BatchInferenceTaskStatus.ValueType  # 4
    FAILED: _BatchInferenceTaskStatus.ValueType  # 5
    CANCELED: _BatchInferenceTaskStatus.ValueType  # 6

class BatchInferenceTaskStatus(_BatchInferenceTaskStatus, metaclass=_BatchInferenceTaskStatusEnumTypeWrapper):
    """Enum representing the status of a batch inference."""

BATCH_INFERENCE_TASK_STATUS_UNSPECIFIED: BatchInferenceTaskStatus.ValueType  # 0
CREATED: BatchInferenceTaskStatus.ValueType  # 1
PENDING: BatchInferenceTaskStatus.ValueType  # 2
IN_PROGRESS: BatchInferenceTaskStatus.ValueType  # 3
COMPLETED: BatchInferenceTaskStatus.ValueType  # 4
FAILED: BatchInferenceTaskStatus.ValueType  # 5
CANCELED: BatchInferenceTaskStatus.ValueType  # 6
global___BatchInferenceTaskStatus = BatchInferenceTaskStatus
